% Computing equilibria in the symmetric information version of the model in
% Livshits, MacGee and Tertilt "Democratization of Credit"
% 
% Uniform distribution of HH types
% rho in [a,1] is HH type = prob of high income (yh),
% (1 - rho) is probability of yl
% RF contract always offered -- no fixed cost
%
% Lender observes borrower type perfectly
%

clear all;
format long;

% Specifying Parameters Values
% Preference paramaters
beta = 0.94;
% Bankruptcy paramaters
gamma = 0.25; %Fraction of earnings burned
% Second period endowment
yh = 30; yl = 10;
abar = 0.9; %worst type in economy

% Specifying Ranges of Parameters Values
% Interest Rate/Bond Price
rsafe = 0.04;           % Benchmark (lowest) risk-free interest rate
qbar = 1/(1 + rsafe);   % Corresponding risk-free bond price

if qbar < beta
    disp('No borrowing - borrowers are too patient. Ignore the following output.')
    pause
end


r_grid = 200; % Number of grid points for comparative statics w.r.t. r
rmin = 1+rsafe;
rmax = 1+rsafe+0.01;
rstep = (rmax-rmin)/(r_grid-1);
rgrid= rmin:rstep:rmax; % Specify grid of risk free interest rates
q_grid = r_grid;
qmin = 1/rmin;
qmax = 1/rmax;
qgrid= ones(size(rgrid))./rgrid; % Specify grid of risk free bond prices

% Chi denotes fixed cost of offering contract
n_grid = 500; % Number of grid points for comparative statics w.r.t. chi
chimin = 0.000025; 
chimax = 0.002;
chistep = (chimax-chimin)/(n_grid-1);
chigrid= chimin:chistep:chimax; % Specify grid of chi

avgincome = ((1+abar)*yh + (1-abar)*yl)/2;
% Size of loan contract: Lbar.
Lbar = gamma*yh;    % Risky borrowing amount
Lbarrf = gamma*yl;  % Risk-free borrowing amount

intlengthps = ( (2*chimin*(1-abar))/(qbar*Lbar) )^(0.5); % Smallest size of the interval
        % served by a single risky contract - that under the lowest fixed cost and the lowest interest rate
max_int = (1-abar)/intlengthps;
ncon = floor(max_int)+1; % Number of risky contracts to potentially check = the max possible number of risky contracts

% Define vectors for keeping track of contracts
qvec = zeros(ncon,1);     % vector to store bond prices
rhovec = zeros(ncon+1,1);   % vector to store cut-offs for contracts

% Define matrices for reporting output for each value of chi, qbar
overheadmat_risky = zeros(q_grid,n_grid);   % matrix to store overhead of risky conrtacts
fractionborrrisky = zeros(q_grid,n_grid);   % matrix to store fraction of poulation borrowing risky
total_defaults = zeros(q_grid,n_grid);      % matrix to store defaults by risky borrowers
agg_default_rate  = zeros(q_grid,n_grid);   % matrix to store default rate risky borrowers
total_borrow  = zeros(q_grid,n_grid);       % matrix to store risky + risk-free borrowing
total_borrow_risky  = zeros(q_grid,n_grid); % matrix to store risky borrowing
nrisky_qbar = zeros(q_grid,n_grid);     % matrix to store number of risky contracts for each value of qbar, chi
minriskyintrate =zeros(q_grid,n_grid);  % matrix to store lowest risky interest rate for each value of qbar, chi
maxriskyintrate =zeros(q_grid,n_grid);  % matrix to store highest risky interest rate for each value of qbar, chi
avgriskyintrate =zeros(q_grid,n_grid);  % matrix to store average risky interest rate for each value of qbar, chi
risky_length =zeros(q_grid,n_grid);     % matrix to store risky contract length for each value of qbar, chi
C_1_agg = zeros(q_grid,n_grid);         % matrix to store aggregate period 1 consumption for each value of qbar, chi
C_2_agg = zeros(q_grid,n_grid);         % matrix to store aggregate period 2 consumption for each value of qbar, chi
Util_equal =zeros(q_grid,n_grid);       % matrix to store average utility for each value of qbar, chi
burnt =zeros(q_grid,n_grid);            % matrix to store deadweight burning for each qbar, chi

% OUTERMOST LOOP - OVER RISK-FREE BOND PRICES
% Loop over values of qbar
for m = 1:q_grid
    qbar =  qgrid(m);
    % Loop over values of chi -- index is n
    for n = 1:n_grid
        chi = chigrid(n);
        % Bond price for the first group
        q1 = qbar - (2*qbar*chi*(1-abar)/Lbar)^(0.5); %Bond price first risky contract
        qvec(1) = q1; % Store risky bond price for interval 1
        i0 = q1/qbar; %Cut-off for first contract
        rhovec(1) = 1; %Top of first risky interval is 1
        rhovec(2) = i0; % Bottom of risky contract 1, also top of risky contract 2
        % Note: rhovec handled differently from other -- first value if top cut-off
        % of first contract, second value is bottom cut-off, etc...

        % Do loop to compute the remaining intervals of the contract.
        
        % The following is the utility difference between the top risky
            % contract and the risk-free contract
            % from the perspective of the highest type borrower (rho=1)
        particrfc = (q1-beta)*Lbar - (qbar-beta)*Lbarrf;
        if particrfc<0
            disp('No risky borrowing for chi=',chi,' and r=',rgrid(m))
            pause
            nrisky=0;
        end
        j=2;   % The following loop moves down the sequence of contracts, with j being the index
        while (particrfc >= 0) && (j<=ncon)
            qvec(j) = qvec(j-1) - (2*qbar*chi*(1-abar)/Lbar)^(0.5);
            rhovec(j+1) = qvec(j)/qbar; % Since rhovec(1) = 1, bottom cut-off is contract# + 1
            
            % Check that the bottom of the interval is not beyond the lower bound of support (abar)
            %   If it is, adjust both the price and the interval
            if rhovec(j+1)<abar
                rhovec(j+1) = abar;
                qvec(j) = qbar*(rhovec(j)+abar)/2 - chi*(1-abar)/(Lbar*(rhovec(j)-abar));
            end
        
            % Check if the top borrower in the bin prefers risky contract to the risk free
            particrfc = (qvec(j) - beta*rhovec(j))*Lbar - beta*(1-rhovec(j))*gamma*yl - (qbar-beta)*Lbarrf;
            if particrfc < 0
                rhovec(j+1) = 0 ;% Set last cut-off to zero.
                nrisky = j-1; % Risky contract j fails the participation constraint.
            end;
            j = j +1; %update counter
        end

        % Remember that the cut-off for riskiest HH served is # contracts + 1
        nrisky_qbar(m,n) = nrisky;  % Store the number of risky contracts
        riskiest = rhovec(nrisky+1); % Store Bottom cut-off of riskiest contract offered in equilibrium
        fractionborrrisky(m,n) = (1 - riskiest)/(1-abar); % Fraction of population with risky borrowing

        % Construct matrix of lengths of each interval
        ilength(1:nrisky) = rhovec(1:nrisky) - rhovec(2:nrisky+1);
        risky_length(m,n) =  rhovec(1) - rhovec(2);
        
        defaultrate = (1-riskiest)/2;   % Average default rate among risky borrowers
        agg_default_rate(m,n) = defaultrate;    % Store default rate among risky borrowers
        defaults = defaultrate*fractionborrrisky(m,n);  % Total defaults
        total_defaults(m,n) = defaults; % Store total defaults
        riskydebt = Lbar*(ilength(1:nrisky)*qvec(1:nrisky))/(1-abar); % Total risky borrowing
        total_borrow_risky(m,n) = riskydebt/avgincome;
        riskfreedebt = Lbarrf*(riskiest-abar)*qbar/(1-abar); % Total riskfree borrowing
        totaloverhead = nrisky*chi; % Total spent on overhead
        total_borrow(m,n) = riskfreedebt + riskydebt; % Total risky and riskfree borrowing
        overheadmat_risky(m,n) = totaloverhead/riskydebt*100; % Overhead as percent of amount borrowed risky
        maxriskyintrate(m,n) = 1/qvec(nrisky) - 1;  % Riskiest interest rate
        minriskyintrate(m,n) = 1/qvec(1) - 1;       % Lowest interest rate on a risky loan
        avgriskyintrate(m,n) = (ones(1,nrisky)*((qvec(1:nrisky)).^(-1) -ones(nrisky,1)))/nrisky;    % Average interest rate on risky loans

        % Compute Social Welfare with equal weights:  c1 + beta c2
        % c1 = q * L
        C_1_agg(m,n) = riskydebt + riskfreedebt;    % Period 1 Aggregate Consumption
        % c2 = Endowment - Repaid - DeadweightLoss of Default
        Agg_end2 = (1 - abar^2)/2* yh + (1 + abar^2)/2* yl;     % Total endowment in period 2
        burnt(m,n) = gamma*yl*defaults;             % Total deadweight loss in default
        Repaid = (fractionborrrisky(m,n)-defaults)*Lbar + ((riskiest-abar)/(1-abar))*Lbarrf;    % Total Repaid
        C_2_agg(m,n) = Agg_end2 - burnt(m,n) - Repaid;
        Util_equal(m,n) = C_1_agg(m,n) + beta*C_2_agg(m,n);

    end; % Loop over chi
end; % Loop over qbar

% Figure 1: Plots chi for the lowest value of Rbar
rgrid_pt = 1;
figure(1)
set(0,'DefaultAxesColorOrder',[0 0 0],...
      'DefaultAxesLineStyleOrder','-|--|:', ...
      'DefaultLineLinewidth',1.5);
subplot(4,2,1)
plot(chigrid(:),nrisky_qbar(rgrid_pt,:));
axis([chigrid(1) chigrid(n) (min(min(nrisky_qbar))-1) (max(max(nrisky_qbar))+1)])
title('A: Number of Risky Contracts','FontSize',12)
xlabel('Fixed Cost (\chi)','FontSize',9)
axis tight
axis tight
subplot(4,2,2)
plot(chigrid(:),fractionborrrisky(rgrid_pt,:));
title('B: Fraction of Population with Risky Debt','FontSize',12)
axis tight
subplot(4,2,3)
plot(chigrid(:),total_defaults(rgrid_pt,:),'blue',chigrid(:),agg_default_rate(rgrid_pt,:));
title('C: Default Rates','FontSize',12)
axis tight
subplot(4,2,4)
plot(chigrid(:),total_borrow_risky(rgrid_pt,:));
title('D: Total Risky Debt','FontSize',12)
axis tight
subplot(4,2,5)
plot(chigrid(:),avgriskyintrate(rgrid_pt,:),chigrid(:),maxriskyintrate(rgrid_pt,:),'blue',chigrid(:),minriskyintrate(rgrid_pt,:),'red');
title('E: Interest Rates','FontSize',12)
axis tight
axis 'auto y'
subplot(4,2,6)
plot(chigrid(:),overheadmat_risky(rgrid_pt,:));
title('F: Overhead Costs as Percent Borrowing','FontSize',12)
set(gcf, 'PaperPositionMode', 'manual');
set(gcf, 'PaperUnits', 'inches');
set(gcf, 'PaperPosition', [0.25 0.25 8.00 10.50]);
saveas(gcf,'chi.fig');
print -deps fig-chi;

% Plots for comparative statics of varying risk-free rate
% Plot for lowest point in chi grid
chi_pt = 1; 
rgrid=(rgrid-1)*100;
figure(3)
set(0,'DefaultAxesColorOrder',[0 0 0],...
      'DefaultAxesLineStyleOrder','-|--|:', ...
      'DefaultLineLinewidth',1.5);
subplot(4,2,1)
plot(rgrid(:),fractionborrrisky(:,chi_pt));
title('A: Fraction of Population with Risky Debt','FontSize',12)
xlabel('Risk-Free Rate','FontSize',9)
axis tight
subplot(4,2,2)
plot(rgrid(:),total_defaults(:,chi_pt),'blue',rgrid(:),agg_default_rate(:,chi_pt));
title('B: Default Rates','FontSize',12)
axis tight
%axis 'auto y'
subplot(4,2,3)
plot(rgrid(:),avgriskyintrate(:,chi_pt),rgrid(:),maxriskyintrate(:,chi_pt),'blue',rgrid(:),minriskyintrate(:,chi_pt),'red');
title('C: Interest Rates','FontSize',12)
axis tight
%axis 'auto y'
subplot(4,2,4)
plot(rgrid(:),overheadmat_risky(:,chi_pt));
title('D: Overhead Costs as Percent Borrowing','FontSize',12)
axis tight
set(gcf, 'PaperPositionMode', 'manual');
set(gcf, 'PaperUnits', 'inches');
set(gcf, 'PaperPosition', [0.25 0.25 8.00 10.50]);
saveas(gcf,'riskfree.fig');
print -deps fig-r;