clear all
set memory 800m
set more off

cd "D:\Dropbox\RA Work\RA Jim\Data"

****************************************************************************************************************************************************************************
****************************************************************************************************************************************************************************
** This file:                                                                                                                                                             **
** 1. divides later years (1998,1995) of bank card holders into new and existing holders, sorted by predicted having-a-bank-credit-card (hereafter called "have-card")    ** 
**    probability according to 1989 probit estimates.                                                                                                                     **
** 2. carries out counterfactuals in delinquency:                                                                                                                         **
**     (1) Case 2: if new cardholders ALL credit card debt are set 0                                                                                                      **
**     (2) Case 3: if existing cardholders bank credit card are reduced by 1.31 (1.24) in 1998 (1995).                                                                    **
**     (3) Robustness 1: if new cardholders BANK credit card debt are set 0                                                                                               **
**     (4) Robustness 2: if new cardholders BANK credit card debt are set 0 & NON-BANK credit card are set at 1989 average                                                **
**   to verify that an increase in population delinquency is due to the extensive margin,i.e. a higher delinquency in issuing bank credit to new bank credit cardholders. **
**Last update: July 15 2015
****************************************************************************************************************************************************************************
****************************************************************************************************************************************************************************






*Variablelist for simplifying the code
*Comman regressors used in deliquency and have-card probit models under all specifications
local comlist1 age 
local comlist2 educ marrd ownhome yradd yrjob i.occup denied_credit selfemp cons_debt_pc sec_debt_pc networth income
*******************************************************************************************************************************
*Specifications: 
* (1) Year 
* (2) Networth (financial asset) cutoff level for regression sample:  
*     e.g. icutoff=3, cutoff=3 million 1989 dollars. 
* (3) Specification of regressors: see Line 
* (4) Monthly payment definition: debt payment (0) or all payments that include rents, auto lease payment and property tax (1)
*******************************************************************************************************************************
local year=1998
local icutoff=5
local ispec=3
local mth_allpay=0



if (`mth_allpay'==0) {
    *Specification 1: No age^2, age^3 and races
	if (`ispec'==1) {
	*Have-card Probit specification, using DSR 
	local hcprobvar `comlist1' `comlist2' c.income#ownhome c.dsr#DSRlev c.liq#LIQlev DSRlev#LIQlev
	*Delinquency probit specification, using DSR 
	local dqprobvar `comlist1' `comlist2' c.dsr#DSRlev c.liq#LIQlev DSRlev#LIQlev
	}
	*Specification 2: With age^2, age^3 but no races
	if (`ispec'==2) {
	*Have-card specification, using DSR
	local hcprobvar `comlist1' quadage cubiage `comlist2' c.income#ownhome  c.dsr#DSRlev c.liq#LIQlev DSRlev#LIQlev
	*Delinquency specification, using DSR
	local dqprobvar `comlist1' quadage cubiage `comlist2' c.dsr#DSRlev c.liq#LIQlev DSRlev#LIQlev
	}
	*Specification 3: With age^2, age^3 and races
	if (`ispec'==3) {
	*Have-card specification, using DSR
	local hcprobvar `comlist1' quadage cubiage `comlist2' c.income#ownhome c.dsr#DSRlev c.liq#LIQlev DSRlev#LIQlev black hispanic raceother 
	*Deliquency specification, using DSR 
	local dqprobvar `comlist1' quadage cubiage `comlist2' c.dsr#DSRlev c.liq#LIQlev DSRlev#LIQlev black hispanic raceother 
    }
	}
	
if (`mth_allpay'==1) {
    *Specification 1: No age^2, age^3 and races
	if (`ispec'==1) {
	*Have-card Probit specification, using FOR 
	local hcprobvar `comlist1' `comlist2' c.income#ownhome c.FOR#FORlev c.liq#LIQlev FORlev#LIQlev
	*Delinquency probit specification, using FOR 
	local dqprobvar `comlist1' `comlist2' c.FOR#FORlev c.liq#LIQlev FORlev#LIQlev
	}
	*Specification 2: With age^2, age^3 but no races
	if (`ispec'==2) {
	*Have-card specification, using FOR
	local hcprobvar `comlist1' quadage cubiage `comlist2' c.income#ownhome  c.FOR#FORlev c.liq#LIQlev FORlev#LIQlev
	*Delinquency specification, using FOR
	local dqprobvar `comlist1' quadage cubiage `comlist2' c.FOR#FORlev c.liq#LIQlev FORlev#LIQlev
	}
	*Specification 3: With age^2, age^3 and races
	if (`ispec'==3) {
	*Have-card specification, using FOR
	local hcprobvar `comlist1' quadage cubiage `comlist2' c.income#ownhome c.FOR#FORlev c.liq#LIQlev FORlev#LIQlev black hispanic raceother 
	*Deliquency specification, using FOR 
	local dqprobvar `comlist1' quadage cubiage `comlist2' c.FOR#FORlev c.liq#LIQlev FORlev#LIQlev black hispanic raceother 
    }
}





********************************
*Divide new and old cardholders
********************************
use basics_1989temp`icutoff'm.dta,clear
egen bcc_all=total(weight*debt_bcc) 
dis bcc_all

*All cardholders summary statistics 
display "Summary statistics in 1989"
sum income networth dsr FOR t_debt debt_cc ownhome age n_hs college marrd white black hispanic raceother selfemp entrep delinq60 [iw=weight]

*Have-card probit estimate in 1989
dis "Specification `ispec'"
prob bcc_hold `hcprobvar' [fw=rnd_weight],difficult
predict bcc_holdhat

*Plotting predicted card holding probability in subsample of cardholders & non-cardholders. 
hist bcc_holdhat if bcc_hold==1 [fw=rnd_weight], color(gs5) fraction xtitle("Predicted Probability of Having a Bank Credit Card (Cardholder)") saving(1989hcardhat_cchold.gph, replace) 
hist bcc_holdhat if bcc_hold==0 [fw=rnd_weight], color(gs10) fraction xtitle("Predicted Probability of Having a Bank Credit Card (Non-Cardholder)") saving(1989hcardhat_ncchold.gph, replace) 

**************************************************************************************************************************
*Update June 5 2015: Find those will-be-new cardholders non-bank credit card debt in 1989 for Robustness 2 (see Line 448-500)
**************************************************************************************************************************
if (`year'==1998) {
	egen nsample1989=total(weight)  
	*Fraction of cardholders in 1989
	gen wbn_perc`icutoff'1=0.5695
	*Fraction of cardholders in 1998 
	gen wbn_perc`icutoff'2=0.6945
	*Presumably HHs that falls between 64.95 and 56.95 percentile of bcc_holdhat in 1989 are the will-be-new cardholders in 1998
	gsort -bcc_holdhat
	gen cum_count_wbn=sum(weight)
	gen wbnew=(cum_count_wbn>wbn_perc`icutoff'1*nsample1989 & cum_count<=wbn_perc`icutoff'2*nsample1989)
	gen debt_nbcc=debt_cc-debt_bcc
	*Check non-bank credit card debt for will-be-new cardholders in 1998 for Robustness 2 (see Line 448-500)
	sum debt_nbcc if wbnew==1 [iw=weight] 
} 






*Predict the probability of credit card holding in 1998 (1995)
use basics_`year'temp`icutoff'm.dta,clear

*Aggregate bank credit issued in 1998 (1995) 
egen bcc_all=total(weight*debt_bcc) 
egen nsample=total(weight)

*Predicting have-card in 1998 (1995) using 1989 estimated probit regression
predict bcc_prob





preserve 
*Cardholders subsample
*Now divide 1998 (1995) cardholders into existing: top 56.96% in 5million cutoff case (56.87% in 3million case) cardholders 
*by predicted have-card probability bcc_prob  & new: non-existing cardholders.  
keep if bcc_hold==1

*Sort highest to lowest probability of have-card
gsort -bcc_prob
gen cum_count=sum(weight)

*Fraction of existing cardholders that carries from 1989
*3 million cutoff case
gen perc_ext3m=0.5687
*5 million cutoff case
gen perc_ext5m=0.5695

*Label new cardholders if the cumulative count is greater than 56.87% / 56.95% of < 3m / 5m cardholders subsample 
gen new=(cum_count>perc_ext`icutoff'm*nsample) 
drop nsample cum_count perc_ext3m perc_ext5m

*Recover to the $1 unit for networth, income and liquid that showed up in probit regression for tabulating summary statistics.
replace networth=networth*1e5
replace income=income*1e5
replace liquid=liquid*1e5

*******************************************************
*Summary stats for all, existing and new cardholders
*******************************************************
*All cardholders
display "All cardholders"
sum income networth dsr FOR t_debt debt_cc debt_bcc ownhome age n_hs college marrd white black hispanic raceother selfemp entrep delinq60 hins ccir [iw=weight]
*Existing cardholders
display "Existing cardholders"
sum income networth dsr FOR t_debt debt_cc debt_bcc ownhome age n_hs college marrd white black hispanic raceother selfemp entrep delinq60 hins ccir [iw=weight] if new==0 
*New cardholders 
display "New cardholders"
sum income networth dsr FOR t_debt debt_cc debt_bcc ownhome age n_hs college marrd white black hispanic raceother selfemp entrep delinq60 hins ccir [iw=weight] if new==1

*Total credit by exsiting & new
display "Total credit in existing & new cardholders" 
table new [iw=weight], content(sum debt_bcc) row
save `year'extnew`icutoff'm`mth_allpay'.dta,replace 



*Restore to sample with both cardholders and non-cardholders 
restore

*Non-cardholders subsample
keep if bcc_hold==0 

*For consistency with cardholders subsample. Recover to $1 unit.
replace networth=networth*1e5
replace income=income*1e5
replace liquid=liquid*1e5

*Note new=1 for new holders /  new=0 for existing holders in the cardholder subsample.
gen new=-1

*Append cardholder subsample
append using `year'extnew`icutoff'm`mth_allpay'.dta

*Now the new dta file has label of new cardholders 
save basics_`year'`icutoff'mtemp`mth_allpay'.dta,replace





***********************************************
*Predicting Prob of delinquency in 1998 (year)      
*Using 1989 probit model                      
***********************************************

****************
*Specification 1/2/3 Probit 
****************
use basics_1989temp`icutoff'm.dta,clear

*Probit estimates of delinquency in 1989
prob delinq60 `dqprobvar' [fw=rnd_weight],difficult
outreg2 using delinq.doc, replace stats(coef se)
estat class

*Predicted delinquency probability in 1989
predict delinq60hat

*Comparison of predicted delinquency: cardholders vs non-cardholders 
display "Actual delinquency in 1989 cardholders vs no card)" 
table bcc_hold [iw=weight], content(mean delinq60) row
display "Predicted delinquency in 1989 (cardholders vs no card)"
table bcc_hold [iw=weight], content(mean delinq60hat) row


************************************************************************************************************************************************
*Predicting delinquency probability in 1998 (1995) using 1989 delinquency probit estimates in non-cardholders, new holders and existing holders
************************************************************************************************************************************************
use basics_`year'`icutoff'mtemp`mth_allpay'.dta,clear

replace networth=networth/1e5
replace income=income/1e5
replace liquid=liquid/1e5

sum bcc_hold [iw=weight]

count if bcc_hold==1
count if bcc_hold==0

*Delinquency rate in data 
display "Actual delinquency in `year' cardholders vs no card, new vs existing cardholders)" 
table bcc_hold new [iw=weight], content(mean delinq60) row col





********
*Case 1
*******
*Probit prediction of delinquency in 1998 (1995)
predict delinq60hat_c1

*Mean predicted delinquency by non-cardholders, new holders and existing holders
display "Predicted delinquency in `year' cardholders vs no card, new vs existing cardholders)" 
table bcc_hold new [iw=weight], content(mean delinq60hat_c1) row col

graph twoway (lfit ccir delinq60hat_c1) (scatter ccir delinq60hat_c1) if bcc_hold==1,ytitle("interest rate") xtitle("predicted default probability") 
graph twoway (lfit ccir delinq60hat_c1) (scatter ccir delinq60hat_c1) if bcc_hold==1 & debt_bcc>0,ytitle("interest rate") xtitle("predicted default probability") 

count if new==1
count if new==0





**************************************************************************
*Case 2:Counterfactual if new cardholders have no access to credit cards
**************************************************************************
preserve 
*Make debt for (all) credit cards to be 0 for new cardholders 
*Erasing off (all) credit card debts from consumer debt & total debt for new cardholders
*Thus, networth, debt payment and all payment shall be adjusted. 
replace networth=networth*1e5
replace income=income*1e5
replace liquid=liquid*1e5

replace cons_debt=cons_debt-debt_cc if new==1 & bcc_hold==1
replace t_debt=t_debt-debt_cc if new==1 & bcc_hold==1
replace t_debtpay=t_debtpay-debtpay_cc if new==1 & bcc_hold==1
replace t_allpay=t_allpay-debtpay_cc if new==1 & bcc_hold==1
replace networth=networth+debt_cc if new==1 & bcc_hold==1
replace debt_cc=0 if new==1 & bcc_hold==1

*Recompute the consumer debt as % of income & DSR ratio
replace cons_debt_pc=cons_debt/income if new==1 & bcc_hold==1
replace dsr=t_debtpay/income*12 if new==1 & bcc_hold==1
replace FOR=t_allpay/income*12 if new==1 & bcc_hold==1

replace DSRlev=0 if dsr<pct_dsr50 & new==1 & bcc_hold==1
replace DSRlev=1 if dsr>=pct_dsr50 & new==1 & bcc_hold==1
replace DSRlev=2 if dsr>=pct_dsr80 & new==1 & bcc_hold==1

replace FORlev=0 if FOR<pct_for50 & new==1 & bcc_hold==1
replace FORlev=1 if FOR>=pct_for50 & new==1 & bcc_hold==1
replace FORlev=2 if FOR>=pct_for80 & new==1 & bcc_hold==1

replace networth=networth/1e5 
replace income=income/1e5
replace liquid=liquid/1e5

sum `dqprobvar' [iw=weight] if new==-1

*Case 2 counterfactual: Model prediction in delinquency  
predict delinq60hat_c2

*Case 2 counterfactual: Mean predicted delinquency by non-cardholders, new holders and existing holders
display "CASE2: Predicted delinquency in `year' cardholders vs no card, new vs existing cardholders)" 
table bcc_hold new [iw=weight], content(mean delinq60hat_c2) row col





restore 
************************************************************************************************************
*Case 3:Counterfactual if existing cardholders' bank credit card debt reduced by 1.31 (1.24) in 1998 (1995) 
************************************************************************************************************
preserve 
replace networth=networth*1e5
replace income=income*1e5
replace liquid=liquid*1e5

*Reduction parameter
if (`year'==1998) {
	gen redc=1.31
	}
if (`year'==1995) {
	gen redc=1.24
	}
if (`year'==2001) {
	gen redc=1.43
	}

*Adjust credit card debt, consumption debt, total debt, debtpayment, all payment and networth by reduction parameter
replace cons_debt=cons_debt-debt_cc+debt_cc/redc if new==0 & bcc_hold==1
replace t_debt=t_debt-debt_cc+debt_cc/redc if new==0 & bcc_hold==1
replace t_debtpay=t_debtpay-debtpay_cc+debtpay_cc/redc if new==0 & bcc_hold==1
replace t_allpay=t_allpay-debtpay_cc+debtpay_cc/redc if new==0 & bcc_hold==1
replace networth=networth+debt_cc-debt_cc/redc if new==0 & bcc_hold==1
replace debt_cc=debt_cc/redc if new==0 & bcc_hold==1

*Recompute the consumer debt as % of income & DSR ratio
replace cons_debt_pc=cons_debt/income if new==0 & bcc_hold==1
replace dsr=t_debtpay/income*12 if new==0 & bcc_hold==1
replace FOR=t_allpay/income*12 if new==0 & bcc_hold==1

replace DSRlev=0 if dsr<pct_dsr50 & new==0 & bcc_hold==1
replace DSRlev=1 if dsr>=pct_dsr50 & new==0 & bcc_hold==1
replace DSRlev=2 if dsr>=pct_dsr80 & new==0 & bcc_hold==1

replace FORlev=0 if FOR<pct_for50 & new==0 & bcc_hold==1
replace FORlev=1 if FOR>=pct_for50 & new==0 & bcc_hold==1
replace FORlev=2 if FOR>=pct_for80 & new==0 & bcc_hold==1

replace networth=networth/1e5
replace income=income/1e5
replace liquid=liquid/1e5

sum `dqprobvar' [iw=weight] if new==0 

sum cons_debt_pc networth dsr FOR DSRlev FORlev if id==40371

*Case 3 counterfactual: Model prediction in delinquency  
predict delinq60hat_c3

*Case 3 counterfactual: Mean predicted delinquency by non-cardholders, new holders and existing holders
display "CASE3: Predicted delinquency in `year' cardholders vs no card, new vs existing cardholders)" 
table bcc_hold new [iw=weight], content(mean delinq60hat_c3) row col





restore
***********************************************************************************************************************
*Further Robustness Check: (Updated June 3 2015) (1) Counterfactual if new holders no access to BANK credit cards only
**********************************************************************************************************************
preserve 
*Make debt for BANK credit cards to be 0
*Erasing off BANK credit card debts from consumer debt & total debt for new credit card holders

replace networth=networth*1e5
replace income=income*1e5
replace liquid=liquid*1e5

replace cons_debt=cons_debt-debt_bcc if new==1 & bcc_hold==1
replace t_debt=t_debt-debt_bcc if new==1 & bcc_hold==1
replace t_debtpay=t_debtpay-debtpay_cc*debt_bcc/debt_cc if new==1 & bcc_hold==1 & debt_cc!=0 
replace t_allpay=t_allpay-debtpay_cc*debt_bcc/debt_cc if new==1 & bcc_hold==1 & debt_cc!=0
replace networth=networth+debt_bcc if new==1 & bcc_hold==1
replace debt_cc=debt_cc-debt_bcc if new==1 & bcc_hold==1 
replace debt_bcc=0 if new==1 & bcc_hold==1

*Recompute the consumer debt as % of income & DSR ratio
replace cons_debt_pc=cons_debt/income if new==1 & bcc_hold==1
replace dsr=t_debtpay/income*12 if new==1 & bcc_hold==1
replace FOR=t_allpay/income*12 if new==1 & bcc_hold==1

replace DSRlev=0 if dsr<pct_dsr50 & new==1 & bcc_hold==1
replace DSRlev=1 if dsr>=pct_dsr50 & new==1 & bcc_hold==1
replace DSRlev=2 if dsr>=pct_dsr80 & new==1 & bcc_hold==1

replace FORlev=0 if FOR<pct_for50 & new==1 & bcc_hold==1
replace FORlev=1 if FOR>=pct_for50 & new==1 & bcc_hold==1
replace FORlev=2 if FOR>=pct_for80 & new==1 & bcc_hold==1

replace networth=networth/1e5 
replace income=income/1e5
replace liquid=liquid/1e5

sum `dqprobvar' [iw=weight] if new==-1

*Case Robust 1 counterfactual: Model prediction in delinquency  
predict delinq60hat_rb1

*Case Robust 1 counterfactual: Mean predicted delinquency by non-cardholders, new holders and existing holders
display "CASE Robust 1: Predicted delinquency in `year' cardholders vs no card, new vs existing cardholders)" 
table bcc_hold new [iw=weight], content(mean delinq60hat_rb1) row col





restore 
***************************************************************************************************************************************************************
*Further Robustness Check: (Updated June 5 2015) (2) Counterfactual if new holders have BANK cc debt 0; non-bank cc debt at their subgroup average in 1989.
*SCF does not track same HHs over years. No debt information of 1998 (1995) new holders in 1989.
*Thus, we pick average non-bank cc debt in the will-be-new subgroup of HHs in 1989 (see Line 108-123) for a proxy. 
***************************************************************************************************************************************************************
preserve 

gen debt_nbcc=debt_cc-debt_bcc 
sum debt_nbcc if new==1 [iw=weight]
gen avg_debt_nbcc=r(mean) 
gen avg_debt_nbcc1989=265.75

*Average non-bank credit card debt in 1989 for the will-be-new (from 1998's view as defined in Line 108-123) cardholders is 265.75  
replace networth=networth*1e5
replace income=income*1e5
replace liquid=liquid*1e5

replace cons_debt=cons_debt-debt_cc+debt_nbcc*avg_debt_nbcc1989/avg_debt_nbcc if new==1 & bcc_hold==1
replace t_debt=t_debt-debt_cc+debt_nbcc*avg_debt_nbcc1989/avg_debt_nbcc  if new==1 & bcc_hold==1
replace t_debtpay=t_debtpay-debtpay_cc+debt_nbcc/debt_cc*debtpay_cc*avg_debt_nbcc1989/avg_debt_nbcc if new==1 & bcc_hold==1 & debt_cc!=0 
replace t_allpay=t_allpay-debtpay_cc+debt_nbcc/debt_cc*debtpay_cc*avg_debt_nbcc1989/avg_debt_nbcc if new==1 & bcc_hold==1 & debt_cc!=0
replace networth=networth+debt_cc-debt_nbcc*avg_debt_nbcc1989/avg_debt_nbcc if new==1 & bcc_hold==1
replace debt_cc=debt_cc-debt_bcc+debt_nbcc*avg_debt_nbcc1989/avg_debt_nbcc if new==1 & bcc_hold==1 
replace debt_bcc=0 if new==1 & bcc_hold==1

*Recompute the consumer debt as % of income & DSR ratio
replace cons_debt_pc=cons_debt/income if new==1 & bcc_hold==1
replace dsr=t_debtpay/income*12 if new==1 & bcc_hold==1
replace FOR=t_allpay/income*12 if new==1 & bcc_hold==1

replace DSRlev=0 if dsr<pct_dsr50 & new==1 & bcc_hold==1
replace DSRlev=1 if dsr>=pct_dsr50 & new==1 & bcc_hold==1
replace DSRlev=2 if dsr>=pct_dsr80 & new==1 & bcc_hold==1

replace FORlev=0 if FOR<pct_for50 & new==1 & bcc_hold==1
replace FORlev=1 if FOR>=pct_for50 & new==1 & bcc_hold==1
replace FORlev=2 if FOR>=pct_for80 & new==1 & bcc_hold==1

replace networth=networth/1e5 
replace income=income/1e5
replace liquid=liquid/1e5

sum `dqprobvar' [iw=weight] if new==-1

*Case Robust 2 counterfactual: Model prediction in delinquency  
predict delinq60hat_rb2

*Case Robust 2 counterfactual: Mean predicted delinquency by non-cardholders, new holders and existing holders
display "CASE Robust 2: Predicted delinquency in `year' cardholders vs no card, new vs existing cardholders)" 
table bcc_hold new [iw=weight], content(mean delinq60hat_rb2) row col

restore 





gen exist=(new==0)
replace new=(new==1) 

mean exist [iw=weight]

mean new [iw=weight]





