clear all
set memory 800m
set more off

*****************************************************************************************
**This file creates probit regression sample from basics_`year'.dta data               **
** for (1) summary statistics of variables in bank card holder and nonholder subsamples**
**     (2) having a bak credit card probit estimation                                  **
** Last update: July 14 2015                                                           **
*****************************************************************************************

cd "D:\Dropbox\RA Work\RA Jim\Data"

***************************************************************************
*Specification Panel:                                                     
* (1) Year 
* (2) Networth (financial asset) cutoff level for regression sample:  
* e.g. icutoff=3, cutoff=3 million 1989 dollars. 
* (3) Price deflators  1: CPI 2: GDP deflator 
***************************************************************************
local year=1998
local icutoff=5
local def=1

use basics_`year'.dta,clear
*****************
*DROP REPLICATES*
*****************

*Droping duplicates that ID in the form of --i, i=2,3,4,5
gen rep_id=real(substr(string(id),-1,.))
keep if rep_id==1

gen rnd_weight=round(weight) 

*Non high school 
gen n_hs=(edcl==1)
*College degree 
gen college=(edcl==4)

*Age higher orders
gen quadage=age^2
gen cubiage=age^3

*Race dummies
gen white=(race==1)
gen black=(race==2)
gen hispanic=(race==3)
gen raceother=(race==5) 

*Entrepreneur dummies
*We define entrepreneurs as who are self employed & have a share of a business with active management. 
gen entrep=(selfemp==1 & biz_equ_hold_am>0) 

*CPI list: constant 1989 dollars
gen cpi1983=80
gen cpi1989=100
gen cpi1992=113
gen cpi1995=124
gen cpi1998=131
gen cpi2001=143
gen cpi2004=152
gen cpi2007=167
gen cpi2010=176

*GDP deflator 
gen ngdpp1989=100
gen ngdpp1992=111
gen ngdpp1995=126
gen ngdpp1998=143
gen ngdpp2001=163
gen ngdpp2004=183
gen ngdpp2007=210


*Convert `year' dollar values into 1998 dollars
if (`year'!=1998) {
   
   if (`def'==1) {
    
	replace income=income*cpi1998/cpi`year'
	replace networth=networth*cpi1998/cpi`year'
	replace t_debt=t_debt*cpi1998/cpi`year'
	replace debt_cc=debt_cc*cpi1998/cpi`year'
	replace debt_bcc=debt_bcc*cpi1998/cpi`year'
	replace subt_fin_asset=subt_fin_asset*cpi1998/cpi`year'
	replace t_debtpay=t_debtpay*cpi1998/cpi`year'
	replace t_allpay=t_allpay*cpi1998/cpi`year'
	replace debtpay_cc=debtpay_cc*cpi1998/cpi`year'
	replace cons_debt=cons_debt*cpi1998/cpi`year'
	replace sec_debt=sec_debt*cpi1998/cpi`year'
    replace liquid=liquid*cpi1998/cpi`year'	
	}
	
   if (`def'==2) {
   
   	replace income=income*ngdpp1998/ngdpp`year'
	replace networth=networth*ngdpp1998/ngdpp`year'
	replace t_debt=t_debt*ngdpp1998/ngdpp`year'
	replace debt_cc=debt_cc*ngdpp1998/ngdpp`year'
	replace debt_bcc=debt_bcc*ngdpp1998/ngdpp`year'
	replace subt_fin_asset=subt_fin_asset*ngdpp1998/ngdpp`year'
	replace t_debtpay=t_debtpay*ngdpp1998/ngdpp`year'
	replace t_allpay=t_allpay*cpi1998/cpi`year'
	replace debtpay_cc=debtpay_cc*ngdpp1998/ngdpp`year'
	replace cons_debt=cons_debt*ngdpp1998/ngdpp`year'
	replace sec_debt=sec_debt*ngdpp1998/ngdpp`year'
    replace liquid=liquid*ngdpp1998/ngdpp`year'

   }
}


*Aggregate bank credit issued in population 
egen tbcc_pop=total(weight*debt_bcc)

*Since 1995, interest rate should redenominated 
if (`year'>=1995) {
	replace ccir=ccir/100
}

****************************
*Getting probit regression sample 
****************************

*Cutoff 3/5 million in 1989 dollars converted to 1998 dollars
if (`def'==1) {
	gen cutoff=`icutoff'*1e6*cpi1998/cpi1989
}
if (`def'==2) {
	gen cutoff=`icutoff'*1e6*ngdpp1998/ngdpp1989
}

keep if age<=65 & networth<cutoff & subt_fin_asset<cutoff  

*Drop outliers: wealthy household that does not have a credit card (unique weight 1313.247 & unique id 34551) for probit convergence. 
if (`year'==1998) {
	drop if id==34551
}

if (`year'==1989) {
	drop if id==7581
	}
if (`year'==1995) {
	drop if id==21941
	}
if (`year'==2001) {
    drop if id==39821 | id==13351
	}

*Aggregate bank credit issued in < `icutoff' sample
egen tbcc_`icutoff'm=total(weight*debt_bcc)


gen cons_debt_pc=cons_debt/income
gen sec_debt_pc=sec_debt/income
gen cclimit_pc=cc_limit/income

*Original SCF documentation: sometimes miss payment & miss payment 2 months behind. 
replace delinq60=(delinq60==1)
 
********************
*Debt/Fee Service Ratio
********************
*Only debt payments 
gen dsr=t_debtpay*12/income
*All kinds of payments including rent, auto leases payment etc.
gen FOR=t_allpay*12/income
 
*Drop outliers that influence the mean in an extreme way.
if (`year'==1998) {
	drop if dsr>100 & dsr!=. 
}
if (`year'==2001) {
	drop if FOR>100 & FOR!=.
}
	
 
*DSR, FOR and liquid level dummies
pctile pct_dsr=dsr [fw=rnd_weight],n(100)

egen total_weight=total(weight)
gen weighted_income=income*weight/total_weight
egen mean_income=total(weighted_income)
 
*Find 50 and 80 percentiles of DSR distribution 
gen pct_dsr50=pct_dsr[50]
gen pct_dsr80=pct_dsr[80]
*Create DSR categorical variables:
*Low DSR: DSR of this HH is below the 50 percentiles of DSR in regression sample 
gen DSRlev=0
*Medium DSR: DSR of this HH is above 50 percentiles of DSR in regression sample 
replace DSRlev=1 if dsr>=pct_dsr[50] 
*High DSR: DSR of this HH is above 50 percentiles of DSR in regression sample 
replace DSRlev=2 if dsr>=pct_dsr[80]
 
*Do the similar thing for FOR 
pctile pct_for=FOR [fw=rnd_weight],n(100)
gen pct_for50=pct_for[50]
gen pct_for80=pct_for[80]
gen FORlev=0 
replace FORlev=1 if FOR>=pct_for[50]
replace FORlev=2 if FOR>=pct_for[80]
 
*Create liquid level categorical variables 
*Low liquid level: HHs that has liquid asset below 1.5% of mean income in regression sample 
gen LIQlev=1
*Medium liquid level:  HHs that has liquid asset between 1.5%  to 4.5% of mean income in regression sample 
replace LIQlev=2 if liquid>=0.015*mean_income & liquid<0.045*mean_income
*High liquid level: HHs that has liquid asset above 4.5% of mean income in regression sample
replace LIQlev=3 if liquid>=0.045*mean_income

*Rescaling values 
replace networth=networth/1e5
replace income=income/1e5
replace liquid=liquid/1e5

save basics_`year'temp`icutoff'm.dta,replace


use basices_`year'temp`icutoff'm.dta,clear 

********************
*SUMMARY STATISTICS*
********************
mean bcc_hold [iw=weight]
mean acc_hold [iw=weight]

dis "Number of Observations in <`icutoff' sample"
dis _N

dis "Aggregate bank credit issued in Population" 
dis tbcc_pop

dis "Aggregate bank credit issued in `icutoff'm Sample"
dis tbcc_`icutoff'm

*Characteristics for cardholders
display("Characteristics for All Cardlholders (1998 dollars) in `year' with `icutoff' million cutoff (1989 dollars)") 
if (`year'<1995) {
	sum income networth dsr FOR t_debt debt_cc debt_bcc ownhome age n_hs college marrd white black hispanic raceother selfemp entrep delinq60 hins if bcc_hold==0 [iw=weight]
	sum income networth dsr FOR t_debt debt_cc debt_bcc ownhome age n_hs college marrd white black hispanic raceother selfemp entrep delinq60 hins if bcc_hold==1 [iw=weight]

	}
if (`year'>=1995) {
	sum income networth dsr FOR t_debt debt_cc debt_bcc ownhome age n_hs college marrd white black hispanic raceother selfemp entrep delinq60 hins ccir if bcc_hold==0 [iw=weight]
	sum income networth dsr FOR t_debt debt_cc debt_bcc ownhome age n_hs college marrd white black hispanic raceother selfemp entrep delinq60 hins ccir if bcc_hold==1 [iw=weight]
}

*************************************
*Probit of having a bank credit card*
*************************************
*Bank credit card hold probit with DSR 
display("Specification (1)") 
probit bcc_hold age educ marrd ownhome yradd  yrjob i.occup denied_credit selfemp cons_debt_pc sec_debt_pc networth income c.income#ownhome c.dsr#DSRlev c.liq#LIQlev DSRlev#LIQlev  [fw=rnd_weight], difficult
outreg2 using ccard_probit`year'(`icutoff'm89dollar`def').doc,replace ctitle(Baseline) stats(coef tstat)
estat class
*Adding age^2 age^3 
display("Specification (2)") 
prob bcc_hold age quadage cubiage educ marrd ownhome yradd  yrjob i.occup denied_credit selfemp cons_debt_pc sec_debt_pc networth income c.income#ownhome c.dsr#DSRlev c.liq#LIQlev DSRlev#LIQlev [fw=rnd_weight], difficult
outreg2 using ccard_probit`year'(`icutoff'm89dollar`def').doc, append ctitle(Adding Age High Orders) stats(coef tstat)
estat class
*Adding races: ommiting white dummy
display("Specification (3)") 
prob bcc_hold age quadage cubiage educ marrd ownhome yradd  yrjob i.occup denied_credit selfemp cons_debt_pc sec_debt_pc networth income c.income#ownhome c.dsr#DSRlev c.liq#LIQlev DSRlev#LIQlev black hispanic raceother [fw=rnd_weight], difficult
outreg2 using ccard_probit`year'(`icutoff'm89dollar`def').doc, append ctitle(Adding Races) stats(coef se)
estat class

*Having card probit with DSR replaced by FOR
display("Specification (1)") 
probit bcc_hold age educ marrd ownhome yradd  yrjob i.occup denied_credit selfemp cons_debt_pc sec_debt_pc networth income c.income#ownhome c.FOR#FORlev c.liq#LIQlev FORlev#LIQlev  [fw=rnd_weight], difficult
outreg2 using ccard_probit`year'FOR(`icutoff'm89dollar`def').doc,replace ctitle(Baseline) stats(coef tstat)
estat class
*Adding age^2 age^3 
display("Specification (2)") 
prob bcc_hold age quadage cubiage educ marrd ownhome yradd  yrjob i.occup denied_credit selfemp cons_debt_pc sec_debt_pc networth income c.income#ownhome c.FOR#FORlev c.liq#LIQlev FORlev#LIQlev [fw=rnd_weight], difficult
outreg2 using ccard_probit`year'FOR(`icutoff'm89dollar`def').doc, append ctitle(Adding Age High Orders) stats(coef tstat)
estat class
*Adding races: ommiting white dummy
display("Specification (3)") 
prob bcc_hold age quadage cubiage educ marrd ownhome yradd  yrjob i.occup denied_credit selfemp cons_debt_pc sec_debt_pc networth income c.income#ownhome c.FOR#FORlev c.liq#LIQlev FORlev#LIQlev black hispanic raceother [fw=rnd_weight], difficult
outreg2 using ccard_probit`year'FOR(`icutoff'm89dollar`def').doc, append ctitle(Adding Races) stats(coef tstat)
estat class



